@@ -1,7 +1,8 @@
 from __future__ import absolute_import
 import weakref
+import numpy as np
 
-from sqlalchemy import Column, Integer, ForeignKey, orm
+from sqlalchemy import Column, Integer, ForeignKey, orm, types
 from sqlalchemy.orm import relationship, backref, Session
 from sqlalchemy.ext.declarative import declared_attr
 
@@ -12,12 +13,32 @@ from .dictionary import get_dict_id, get_or_create_dictionary_item
 from .timestep import TimeStep
 import six
 
+class UnsignedInteger(types.TypeDecorator):
+    """Stores an unsigned int64 as a signed int64"""
+
+    impl = types.Integer
+
+    cache_ok = True
+
+    def process_bind_param(self, value, dialect):
+        return np.uint64(value).astype(np.int64)
+
+    def process_result_value(self, value, dialect):
+        if value:
+            if type(value) is bytes:
+                return np.frombuffer(value, dtype=np.uint64)[0]
+            else:
+                return np.int64(value).astype(np.uint64)
+        else:
+            return None
+
 class Halo(Base):
     __tablename__= "halos"
 
-    id = Column(Integer, primary_key=True)
-    halo_number = Column(Integer)
-    finder_id = Column(Integer)
+    id = Column(Integer, primary_key=True) #the unique ID value of the database object created for this halo
+    halo_number = Column(Integer) #by default this will be the halo's rank in terms of particle count
+    finder_id = Column(UnsignedInteger) #raw halo ID from the halo catalog
+    finder_offset = Column(Integer) #index of halo within halo catalog, primary identifier used when reading catalog/simulation data
     timestep_id = Column(Integer, ForeignKey('timesteps.id'))
     timestep = relationship(TimeStep, backref=backref(
         'objects', order_by=halo_number, cascade='all', lazy='dynamic'), cascade='save-update, merge')
@@ -72,10 +93,11 @@ class Halo(Base):
                     return c.tag
         raise ValueError("Unknown object typecode %d",typecode)
 
-    def __init__(self, timestep, halo_number, finder_id, NDM, NStar, NGas, object_typecode=0):
+    def __init__(self, timestep, halo_number, finder_id, finder_offset, NDM, NStar, NGas, object_typecode=0):
         self.timestep = timestep
         self.halo_number = int(halo_number)
         self.finder_id = int(finder_id)
+        self.finder_offset = int(finder_offset)
         self.NDM = int(NDM)
         self.NStar = int(NStar)
         self.NGas = int(NGas)
@@ -120,12 +142,17 @@ class Halo(Base):
         handler this can be None or 'partial' (in a normal session) and, when running inside an MPI session,
         'server' or 'server-partial'. See https://pynbody.github.io/tangos/mpi.html.
         """
-        if self.finder_id is None:
+        halo_number = self.halo_number
+        if not hasattr(self, "finder_id"):
             finder_id = self.halo_number # backward compatibility
         else:
-            finder_id = self.finder_id 
+            finder_id = self.finder_id
+        if not hasattr(self, "finder_offset"):
+            finder_offset = finder_id
+        else:
+            finder_offset = self.finder_offset
 
-        return self.handler.load_object(self.timestep.extension, finder_id, object_typetag=self.tag, mode=mode)
+        return self.handler.load_object(self.timestep.extension, finder_id, finder_offset, object_typetag=self.tag, mode=mode)
 
     def calculate(self, calculation, return_description=False):
         """Use the live-calculation system to calculate a user-specified function of the stored data.
@@ -390,7 +417,7 @@ class Tracker(Halo):
     tag = "tracker"
 
     def __init__(self, timestep, halo_number):
-        super(Tracker, self).__init__(timestep, halo_number, halo_number, 0,0,0,
+        super(Tracker, self).__init__(timestep, halo_number, halo_number, halo_number, 0,0,0,
                                  self.__mapper_args__['polymorphic_identity'])
 
     @property
@@ -449,7 +476,7 @@ class PhantomHalo(Halo):
     tag = "phantom"
 
     def __init__(self, timestep, halo_number, finder_id):
-        super(PhantomHalo, self).__init__(timestep, halo_number, finder_id, 0,0,0,
+        super(PhantomHalo, self).__init__(timestep, halo_number, finder_id, finder_id, 0,0,0,
                                  self.__mapper_args__['polymorphic_identity'])
 
 TimeStep.phantoms = orm.relationship(Halo, cascade='all', lazy='dynamic',
