@@ -109,7 +109,7 @@ def _db_import_export(target_session, from_session, *sims):
 
             logger.info("Transferring objects for %s", ts_ext)
             for h_ext in ts_ext.objects:
-                h = Halo(ts, h_ext.halo_number, h_ext.finder_id, h_ext.NDM,
+                h = Halo(ts, h_ext.halo_number, h_ext.finder_id, h_ext.finder_offset, h_ext.NDM,
                          h_ext.NStar, h_ext.NGas, h_ext.object_typecode)
                 h.external_id = h_ext.id
                 halos_this_ts.append(h)
@@ -296,9 +296,9 @@ def add_tracker(halo, size=None):
     core.get_default_session().commit()
 
 
-def grep_run(st):
+def grep_run(opts):
     run = core.get_default_session().query(Creator).filter(
-        Creator.command_line.like("%" + st + "%")).all()
+        Creator.command_line.like("%" + opts.query + "%")).all()
     for r in run:
         print(r.id, end=' ')
 
@@ -447,6 +447,12 @@ def get_argument_parser_and_subparsers():
     subparse_recentruns.add_argument("num", type=int,
                                      help="The number of runs to display, starting with the most recent")
 
+    subparse_greprun = subparse.add_parser("grep-runs",
+                                              help="List IDs of runs matching command line")
+    subparse_greprun.set_defaults(func=grep_run)
+    subparse_greprun.add_argument("query", type=str,
+                                     help="The sub-string to search for in the command line")
+
     # The following subcommands currently do not work and is disabled:
     """
     subparse_remruns = subparse.add_parser("rm", help="Remove a simulation from the database")
